@@ -24,23 +24,14 @@
 
 from builtins import super
 
-import vtk
+from vtkplotlib._get_vtk import vtk
 import numpy as np
-from matplotlib import colors
-import os
-import sys
-from pathlib2 import Path
-from vtk.util.numpy_support import (
-                                    numpy_to_vtk,
-                                    numpy_to_vtkIdTypeArray,
-                                    vtk_to_numpy,
-                                    )
 
 
 
-from vtkplotlib.plots.BasePlot import BasePlot
+from vtkplotlib.plots.BasePlot import Base2DPlot
 
-class Text(BasePlot):
+class Text(Base2DPlot):
     """2D text at a fixed point on the window (independent of camera
     position / orientation).
 
@@ -56,12 +47,11 @@ class Text(BasePlot):
     :param color: The color of the text, defaults to white.
     :type color: str, 3-tuple, 4-tuple, optional
 
-    :param opacity: The translucency of the text, 0 is invisible, 1 is solid, defaults to solid.
+    :param opacity: The translucency of the plot, from `0` invisible to `1` solid, defaults to `1`.
     :type opacity: float, optional
 
-    :param fig: The figure to plot into, can be None, defaults to vpl.gcf().
-    :type fig: vpl.figure, vpl.QtFigure, optional
-
+    :param fig: The figure to plot into, can be None, defaults to :meth:`vtkplotlib.gcf`.
+    :type fig: :class:`vtkplotlib.figure`, :class:`vtkplotlib.QtFigure`, optional
 
     :return: The text plot object.
     :rtype: vtkplotlib.plots.Text.Text
@@ -123,13 +113,12 @@ class Text(BasePlot):
 
 
 def resize_event_cb(*args):
-    print(args)
+    # print(args)
     self.actor.SetPosition(*(i // 2 for i in fig.render_size))
 
 
 if __name__ == "__main__":
     import vtkplotlib as vpl
-    import vtk
 
     fig = vpl.figure()
     fig.renWin.AddObserver(vtk.vtkCommand.ModifiedEvent, resize_event_cb)
